diff --git a/web/pgadmin/authenticate/__init__.py b/web/pgadmin/authenticate/__init__.py
index 8d08b34e8..d637e32dd 100644
--- a/web/pgadmin/authenticate/__init__.py
+++ b/web/pgadmin/authenticate/__init__.py
@@ -61,7 +61,7 @@ class AuthenticateModule(PgAdminModule):
 blueprint = AuthenticateModule(MODULE_NAME, __name__, static_url_path='')
 
 
-@blueprint.route('/login', endpoint='login', methods=['POST'])
+@blueprint.route('/login', endpoint='login', methods=['GET', 'POST'])
 def login():
     """
     Entry point for all the authentication sources.
diff --git a/web/pgadmin/authenticate/oauth2.py b/web/pgadmin/authenticate/oauth2.py
index f84299e4c..07d398380 100644
--- a/web/pgadmin/authenticate/oauth2.py
+++ b/web/pgadmin/authenticate/oauth2.py
@@ -48,7 +48,7 @@ def init_app(app):
     blueprint = Oauth2Module(MODULE_NAME, __name__, static_url_path='')
 
     @blueprint.route('/authorize', endpoint="authorize",
-                     methods=['POST'])
+                     methods=['GET', 'POST'])
     @pgCSRFProtect.exempt
     def oauth_authorize():
         auth_obj = session['auth_obj']
@@ -66,7 +66,7 @@ def init_app(app):
         return redirect(get_post_login_redirect())
 
     @blueprint.route('/logout', endpoint="logout",
-                     methods=['POST'])
+                     methods=['GET', 'POST'])
     @pgCSRFProtect.exempt
     def oauth_logout():
         if not current_user.is_authenticated:
diff --git a/web/pgadmin/browser/__init__.py b/web/pgadmin/browser/__init__.py
index 90dcd40e6..c7a078d60 100644
--- a/web/pgadmin/browser/__init__.py
+++ b/web/pgadmin/browser/__init__.py
@@ -923,7 +923,7 @@ def signal_runtime():
 
 if hasattr(config, 'SECURITY_CHANGEABLE') and config.SECURITY_CHANGEABLE:
     @blueprint.route("/change_password", endpoint="change_password",
-                     methods=['POST'])
+                     methods=['GET', 'POST'])
     @pgCSRFProtect.exempt
     @login_required
     def change_password():
@@ -1011,7 +1011,7 @@ if hasattr(config, 'SECURITY_RECOVERABLE') and config.SECURITY_RECOVERABLE:
             user=user, token=token)
 
     @blueprint.route("/reset_password", endpoint="forgot_password",
-                     methods=['POST'])
+                     methods=['GET', 'POST'])
     @pgCSRFProtect.exempt
     @anonymous_user_required
     def forgot_password():
diff --git a/web/pgadmin/browser/server_groups/servers/databases/schemas/views/__init__.py b/web/pgadmin/browser/server_groups/servers/databases/schemas/views/__init__.py
index 7bb2ee411..9fa345dda 100644
--- a/web/pgadmin/browser/server_groups/servers/databases/schemas/views/__init__.py
+++ b/web/pgadmin/browser/server_groups/servers/databases/schemas/views/__init__.py
@@ -181,7 +181,7 @@ class Message(IProcessDesc):
 
         if s is None:
             return gettext("Not available")
-        return html.safe_str("{0} ({1}:{2})".format(s.name, s.host, s.port))
+        return "{0} ({1}:{2})".format(s.name, s.host, s.port)
 
     def details(self, cmd, args):
         return {
diff --git a/web/pgadmin/tools/backup/__init__.py b/web/pgadmin/tools/backup/__init__.py
index 8eebaa505..87ed57f8a 100644
--- a/web/pgadmin/tools/backup/__init__.py
+++ b/web/pgadmin/tools/backup/__init__.py
@@ -115,9 +115,6 @@ class BackupMessage(IProcessDesc):
         host = manager.local_bind_host if manager.use_ssh_tunnel else s.host
         port = manager.local_bind_port if manager.use_ssh_tunnel else s.port
 
-        s.name = html.safe_str(s.name)
-        host = html.safe_str(host)
-        port = html.safe_str(port)
         return "{0} ({1}:{2})".format(s.name, host, port)
 
     @property
@@ -140,9 +137,7 @@ class BackupMessage(IProcessDesc):
             return _(
                 "Backing up an object on the server '{0}' "
                 "from database '{1}'"
-            ).format(server_name,
-                     html.safe_str(self.database)
-                     )
+            ).format(server_name, self.database)
         if self.backup_type == BACKUP.GLOBALS:
             return _("Backing up the global objects on "
                      "the server '{0}'").format(
diff --git a/web/pgadmin/tools/import_export/__init__.py b/web/pgadmin/tools/import_export/__init__.py
index d7890bc7c..b5c463039 100644
--- a/web/pgadmin/tools/import_export/__init__.py
+++ b/web/pgadmin/tools/import_export/__init__.py
@@ -98,7 +98,7 @@ class IEMessage(IProcessDesc):
 
         if s is None:
             return _("Not available")
-        return html.safe_str("{0} ({1}:{2})".format(s.name, s.host, s.port))
+        return "{0} ({1}:{2})".format(s.name, s.host, s.port)
 
     @property
     def message(self):
@@ -107,9 +107,7 @@ class IEMessage(IProcessDesc):
             "Copying table data '{0}.{1}' on database '{2}' "
             "and server '{3}'"
         ).format(
-            html.safe_str(self.schema),
-            html.safe_str(self.table),
-            html.safe_str(self.database),
+            self.schema, self.table, self.database,
             self.get_server_name()
         )
 
diff --git a/web/pgadmin/tools/maintenance/__init__.py b/web/pgadmin/tools/maintenance/__init__.py
index facc8aa18..950930a0e 100644
--- a/web/pgadmin/tools/maintenance/__init__.py
+++ b/web/pgadmin/tools/maintenance/__init__.py
@@ -73,9 +73,6 @@ class Message(IProcessDesc):
         host = manager.local_bind_host if manager.use_ssh_tunnel else s.host
         port = manager.local_bind_port if manager.use_ssh_tunnel else s.port
 
-        s.name = html.safe_str(s.name)
-        host = html.safe_str(host)
-        port = html.safe_str(port)
         return "{0} ({1}:{2})".format(s.name, host, port)
 
     def get_op(self):
diff --git a/web/pgadmin/tools/restore/__init__.py b/web/pgadmin/tools/restore/__init__.py
index e823bdf06..18e8a88f4 100644
--- a/web/pgadmin/tools/restore/__init__.py
+++ b/web/pgadmin/tools/restore/__init__.py
@@ -89,9 +89,6 @@ class RestoreMessage(IProcessDesc):
         host = manager.local_bind_host if manager.use_ssh_tunnel else s.host
         port = manager.local_bind_port if manager.use_ssh_tunnel else s.port
 
-        s.name = html.safe_str(s.name)
-        host = html.safe_str(host)
-        port = html.safe_str(port)
         return "{0} ({1}:{2})".format(s.name, host, port)
 
     @property
